@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_BLOCK_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_BLOCK_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/blktrace_api.h>
 #include <linux/blkdev.h>
 #include <linux/trace_seq.h>
@@ -135,7 +135,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS_CODE(block_rq_with_error,
 		size_t cmd_len;
 	),
 
-	TP_code(
+	TP_code_pre(
 		if (rq->cmd_type == REQ_TYPE_BLOCK_PC) {
 			tp_locvar->sector = 0;
 			tp_locvar->nr_sector = 0;
@@ -159,7 +159,9 @@ LTTNG_TRACEPOINT_EVENT_CLASS_CODE(block_rq_with_error,
 			rq->cmd_flags, blk_rq_bytes(rq))
 		ctf_sequence_hex(unsigned char, cmd,
 			tp_locvar->cmd, size_t, tp_locvar->cmd_len)
-	)
+	),
+
+	TP_code_post()
 )
 
 /**
@@ -201,7 +203,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(block_rq_with_error, block_rq_requeue,
 	|| LTTNG_KERNEL_RANGE(3,4,91, 3,5,0)		\
 	|| LTTNG_KERNEL_RANGE(3,2,58, 3,3,0)		\
 	|| LTTNG_UBUNTU_KERNEL_RANGE(3,13,11,28, 3,14,0,0)	\
-	|| LTTNG_RHEL_KERNEL_RANGE(3,10,0,7,1, 3,11,0,0,0))
+	|| LTTNG_RHEL_KERNEL_RANGE(3,10,0,229,0,0, 3,11,0,0,0,0))
 
 /**
  * block_rq_complete - block IO operation completed by device driver
@@ -227,7 +229,7 @@ LTTNG_TRACEPOINT_EVENT_CODE(block_rq_complete,
 		size_t cmd_len;
 	),
 
-	TP_code(
+	TP_code_pre(
 		if (rq->cmd_type == REQ_TYPE_BLOCK_PC) {
 			tp_locvar->cmd = rq->cmd;
 			tp_locvar->cmd_len = rq->cmd_len;
@@ -247,7 +249,9 @@ LTTNG_TRACEPOINT_EVENT_CODE(block_rq_complete,
 			rq->cmd_flags, nr_bytes)
 		ctf_sequence_hex(unsigned char, cmd,
 			tp_locvar->cmd, size_t, tp_locvar->cmd_len)
-	)
+	),
+
+	TP_code_post()
 )
 
 #else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0)) */
@@ -286,7 +290,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS_CODE(block_rq,
 		size_t cmd_len;
 	),
 
-	TP_code(
+	TP_code_pre(
 		if (rq->cmd_type == REQ_TYPE_BLOCK_PC) {
 			tp_locvar->sector = 0;
 			tp_locvar->nr_sector = 0;
@@ -314,7 +318,9 @@ LTTNG_TRACEPOINT_EVENT_CLASS_CODE(block_rq,
 		ctf_sequence_hex(unsigned char, cmd,
 			tp_locvar->cmd, size_t, tp_locvar->cmd_len)
 		ctf_array_text(char, comm, current->comm, TASK_COMM_LEN)
-	)
+	),
+
+	TP_code_post()
 )
 
 /**
@@ -833,5 +839,4 @@ LTTNG_TRACEPOINT_EVENT(block_rq_remap,
 #endif /* LTTNG_TRACE_BLOCK_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
-
+#include <probes/define_trace.h>
