@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_LTTNG_TEST_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_LTTNG_TEST_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/types.h>
 #include <linux/version.h>
 
@@ -25,10 +25,12 @@ LTTNG_TRACEPOINT_EVENT(lttng_test_filter_event,
 		ctf_sequence_text(char, seqfield2, text, size_t, textlen)
 		ctf_string(stringfield, text)
 		ctf_string(stringfield2, etext)
+		ctf_sequence_bitfield(long, bitfield_seq, values, uint8_t, 3)
+		ctf_array_bitfield(long, bitfield_array, values, 3)
 	)
 )
 
 #endif /*  LTTNG_TRACE_LTTNG_TEST_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
