@@ -4,11 +4,10 @@
 #if !defined(LTTNG_TRACE_MM_VMSCAN_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_MM_VMSCAN_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/types.h>
 #include <linux/mm.h>
 #include <linux/memcontrol.h>
-#include <trace/events/gfpflags.h>
 #include <linux/version.h>
 
 #ifndef _TRACE_VMSCAN_DEF
@@ -465,4 +464,4 @@ LTTNG_TRACEPOINT_EVENT_MAP(update_swap_token_priority,
 #endif /* LTTNG_TRACE_MM_VMSCAN_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
