@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_SIGNAL_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_SIGNAL_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/version.h>
 
 #ifndef _TRACE_SIGNAL_DEF
@@ -150,4 +150,4 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(signal_queue_overflow, signal_lose_info,
 #endif /* LTTNG_TRACE_SIGNAL_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
