@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_TIMER_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_TIMER_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 
 #ifndef _TRACE_TIMER_DEF_
 #define _TRACE_TIMER_DEF_
@@ -283,4 +283,4 @@ LTTNG_TRACEPOINT_EVENT_MAP(itimer_expire,
 #endif /*  LTTNG_TRACE_TIMER_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
