@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_WORKQUEUE_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_WORKQUEUE_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/workqueue.h>
 #include <linux/version.h>
 
@@ -168,4 +168,4 @@ LTTNG_TRACEPOINT_EVENT(workqueue_destruction,
 #endif /*  LTTNG_TRACE_WORKQUEUE_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
