@@ -23,11 +23,11 @@
 #include <linux/module.h>
 #include <linux/slab.h>
 #include <linux/sched.h>
-#include "lttng-events.h"
-#include "wrapper/ringbuffer/frontend_types.h"
-#include "wrapper/vmalloc.h"
-#include "wrapper/kallsyms.h"
-#include "lttng-tracer.h"
+#include <lttng-events.h>
+#include <wrapper/ringbuffer/frontend_types.h>
+#include <wrapper/vmalloc.h>
+#include <wrapper/kallsyms.h>
+#include <lttng-tracer.h>
 
 static
 int (*wrapper_task_prio_sym)(struct task_struct *t);
@@ -66,6 +66,7 @@ void prio_record(struct lttng_ctx_field *field,
 
 static
 void prio_get_value(struct lttng_ctx_field *field,
+		struct lttng_probe_ctx *lttng_probe_ctx,
 		union lttng_ctx_value *value)
 {
 	value->s64 = wrapper_task_prio_sym(current);
