@@ -25,7 +25,7 @@
 #include <linux/mutex.h>
 #include <linux/seq_file.h>
 
-#include "lttng-events.h"
+#include <lttng-events.h>
 
 /*
  * probe list is protected by sessions lock.
