@@ -28,8 +28,8 @@
 #include <linux/jhash.h>
 #include <linux/module.h>
 
-#include "lttng-tracepoint.h"
-#include "wrapper/list.h"
+#include <lttng-tracepoint.h>
+#include <wrapper/list.h>
 
 /*
  * Protect the tracepoint table. lttng_tracepoint_mutex nests within
